package org.example;

import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.scheduling.annotation.EnableScheduling;

import java.time.Instant;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.ZoneId;
import java.time.ZoneOffset;
import java.util.Scanner;

@SpringBootApplication
@EnableScheduling
public class ReminderApplication implements CommandLineRunner {

	private final ReminderService reminderService;

	public static void main(String[] args) {
		SpringApplication.run(ReminderApplication.class, args);
	}

	public ReminderApplication(ReminderService reminderService) {
		this.reminderService = reminderService;
	}

	@Override
	public void run(String[] args) {
		try (Scanner scanner = new Scanner(System.in)) {
			System.out.println("Enter reminders with time and text...");
			while (true)
				try {
					String line = scanner.nextLine();
					if (line.isEmpty()) break;
					String[] tokens = line.split("\\s+", 2);
					LocalTime time = LocalTime.parse(tokens[0]);
					reminderService.scheduleReminder(getInstant(time), tokens[1]);
				} catch (Exception ex) {
					System.out.println("Error: " + ex.getMessage());
				}
		}
		System.exit(0);
	}

	private Instant getInstant(LocalTime time) {
		LocalDateTime dateTime = time.atDate(LocalDate.now());
		ZoneOffset zoneOffSet = ZoneId.systemDefault().getRules().getOffset(dateTime);
		return dateTime.toInstant(zoneOffSet);
	}
}
